@@ -16,6 +16,7 @@ typedef void ABSTRACT_VALUE;
 struct scope_stack {
   int level;
   int max;
+  int _init_count;
   struct ProLoopState* root;
 };
 
@@ -30,11 +31,10 @@ struct ProLoopState {
 int curScopeLevel(struct scope_stack*);
 struct ProLoopState* getCurrentScope(struct scope_stack*);
 struct ProLoopState* getScope(struct scope_stack*, int depth);
-void popScope();
+void popScope(struct scope_stack* scopestack);
 /* maxloop = number of loops - 1 in * loops_AV */
 void pushScope2(struct scope_stack*, int maxloop, void *loops_AV);
-void setRootScope(struct scope_stack*, void* param_HV);
-void Scope_init(struct scope_stack* scopestack);
+void Scope_init_root(struct scope_stack*, void* param_HV);
 void Scope_free(struct scope_stack* scopestack);
 
 #endif /* _PROSCOPE_H */
